var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber =
[
    [ "com::sun::star::text::DependentTextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#ad9e399bc7074c22e5069ac12b2162aa1", null ],
    [ "DataBaseName", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#ae885c1a651d501e99aeffdf65fb8b625", null ],
    [ "DataBaseResource", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#aceebc5c63663ba4a0418a24a2f0a0aaf", null ],
    [ "DataBaseURL", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#a125ebe53f61fca10ac425d4d2ad1945e", null ],
    [ "DataCommandType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#ab9bbb127f28a3d0937d1e525c9758082", null ],
    [ "DataTableName", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#a2ad46588e78c0c873e9faa8992dbd8e7", null ],
    [ "NumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#ae3dc42096fd541eb9a8b3c3e0654582b", null ],
    [ "SetNumber", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1DatabaseSetNumber.html#a8ea80f0392537c027ec828652d18478c", null ]
];